[PATCH 4/8] libtest: Rename ValidCache in FullCache

Sebastian Huber sebastian.huber at embedded-brains.de
Fri Nov 13 10:07:53 UTC 2020


This name better reflects the execution envirnoment in which the cache
is fully loaded with valid data unrelated to the body request handler.
---
 cpukit/include/rtems/test.h           |  2 +-
 cpukit/libtest/t-test-rtems-measure.c | 10 +++++-----
 2 files changed, 6 insertions(+), 6 deletions(-)

diff --git a/cpukit/include/rtems/test.h b/cpukit/include/rtems/test.h
index ae81aac4d0..509c7d0213 100644
--- a/cpukit/include/rtems/test.h
+++ b/cpukit/include/rtems/test.h
@@ -2557,7 +2557,7 @@ typedef struct {
 
 #define T_MEASURE_RUNTIME_REPORT_SAMPLES 0x2
 
-#define T_MEASURE_RUNTIME_DISABLE_VALID_CACHE 0x10
+#define T_MEASURE_RUNTIME_DISABLE_FULL_CACHE 0x10
 
 #define T_MEASURE_RUNTIME_DISABLE_HOT_CACHE 0x20
 
diff --git a/cpukit/libtest/t-test-rtems-measure.c b/cpukit/libtest/t-test-rtems-measure.c
index ea3f0ab3e2..0607312701 100644
--- a/cpukit/libtest/t-test-rtems-measure.c
+++ b/cpukit/libtest/t-test-rtems-measure.c
@@ -478,7 +478,7 @@ get_maximum_retries(const T_measure_runtime_request *req)
 }
 
 static void
-measure_valid_cache(T_measure_runtime_context *ctx,
+measure_full_cache(T_measure_runtime_context *ctx,
     const T_measure_runtime_request *req)
 {
 	size_t sample_count;
@@ -488,7 +488,7 @@ measure_valid_cache(T_measure_runtime_context *ctx,
 	size_t i;
 	T_time begin;
 
-	measure_variant_begin(req->name, "ValidCache");
+	measure_variant_begin(req->name, "FullCache");
 	begin = T_now();
 	sample_count = ctx->sample_count;
 	samples = ctx->samples;
@@ -803,11 +803,11 @@ T_measure_runtime(T_measure_runtime_context *ctx,
     const T_measure_runtime_request *req)
 {
 	/*
 	 * Do ValidCache variant before HotCache to get a good overall cache
 	 * state for the HotCache variant.
 	 */
-	if ((req->flags & T_MEASURE_RUNTIME_DISABLE_VALID_CACHE) == 0) {
-		measure_valid_cache(ctx, req);
+	if ((req->flags & T_MEASURE_RUNTIME_DISABLE_FULL_CACHE) == 0) {
+		measure_full_cache(ctx, req);
 	}
 
 	if ((req->flags & T_MEASURE_RUNTIME_DISABLE_HOT_CACHE) == 0) {
@@ -803,11 +803,11 @@ T_measure_runtime(T_measure_runtime_context *ctx,
 {
 	/*
-	 * Do ValidCache variant before HotCache to get a good overall cache
+	 * Do FullCache variant before HotCache to get a good overall cache
 	 * state for the HotCache variant.
 	 */
-- 
2.26.2



More information about the devel mailing list